@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless;
-$Footprintless::VERSION = '1.07';
+$Footprintless::VERSION = '1.08';
 # ABSTRACT: A utility for managing systems with minimal installs
 # PODNAME: Footprintless
 
@@ -19,6 +19,11 @@ sub new {
     return bless( {}, shift )->_init(@_);
 }
 
+sub agent {
+    my ( $self, @options ) = @_;
+    $self->{factory}->agent(@options);
+}
+
 sub AUTOLOAD {
     my ( $self, @args ) = @_;
     my $method = $AUTOLOAD;
@@ -26,11 +31,6 @@ sub AUTOLOAD {
     $self->{factory}->$method(@args);
 }
 
-sub agent {
-    my ( $self, @args ) = @_;
-    $self->{factory}->agent(@args);
-}
-
 sub command_options_factory {
     my ( $self, @args ) = @_;
     $self->{factory}->command_options_factory(@args);
@@ -189,7 +189,7 @@ Footprintless - A utility for managing systems with minimal installs
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 SYNOPSIS
 
@@ -379,9 +379,22 @@ or subclass of C<Footprintless::Localhost>.
 
 =head1 METHODS
 
-=head2 agent()
+=head2 agent(%options)
 
-Returns the L<agent|LWP::UserAgent> used by this instance. 
+Returns a new L<agent|LWP::UserAgent> obtained from C<agent> in
+L<Footprintless::Util>. The supported options are:
+
+=over 4
+
+=item cookie_jar
+
+A hashref for storing cookies.  If not supplied, cookies will be ignored.
+
+=item timeout
+
+The http request timeout.
+
+=back
 
 =head2 command_options_factory()
 
