@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Factory;
-$Footprintless::Factory::VERSION = '1.07';
+$Footprintless::Factory::VERSION = '1.08';
 # ABSTRACT: The default factory for footprintless modules
 # PODNAME: Footprintless::Factory
 
@@ -18,13 +18,9 @@ sub new {
 }
 
 sub agent {
-    my ( $self, %options ) = @_;
+    my ( $self, @options ) = @_;
 
-    unless ( $self->{agent} ) {
-        $self->{agent} = Footprintless::Util::agent(%options);
-    }
-
-    return $self->{agent};
+    return Footprintless::Util::agent(@options);
 }
 
 sub AUTOLOAD {
@@ -174,7 +170,7 @@ Footprintless::Factory - The default factory for footprintless modules
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 DESCRIPTION
 
@@ -188,9 +184,22 @@ Creates a new factory configured by C<$entities>.
 
 =head1 METHODS
 
-=head2 agent()
+=head2 agent(%options)
 
-Returns the L<agent|LWP::UserAgent> used by this instance. 
+Returns a new L<agent|LWP::UserAgent> obtained from C<agent> in
+L<Footprintless::Util>. The supported options are:
+
+=over 4
+
+=item cookie_jar
+
+A hashref for storing cookies.  If not supplied, cookies will be ignored.
+
+=item timeout
+
+The http request timeout.
+
+=back
 
 =head2 command_options(%spec)
 
