@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Util;
-$Footprintless::Util::VERSION = '1.07';
+$Footprintless::Util::VERSION = '1.08';
 # ABSTRACT: A utility method package for common functionality in Footprintless
 # PODNAME: Footprintless::Util
 
@@ -32,6 +32,7 @@ my $logger = Log::Any->get_logger();
 
 sub agent {
     my (%options) = @_;
+
     require LWP::UserAgent;
     my $agent = LWP::UserAgent->new();
     $agent->env_proxy();
@@ -247,7 +248,7 @@ Footprintless::Util - A utility method package for common functionality in Footp
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 SYNOPSIS
 
@@ -281,9 +282,22 @@ This module contains common utility methods used by Footprintless.
 
 =head1 FUNCTIONS
 
-=head2 agent()
+=head2 agent(%options)
 
-Returns a new instance of C<LWP::UserAgent> configured with C<env_proxy>.
+Returns a new L<agent|LWP::UserAgent>.  By default C<env_proxy> is set.
+The supported options are:
+
+=over 4
+
+=item cookie_jar
+
+A hashref for storing cookies.  If not supplied, cookies will be ignored.
+
+=item timeout
+
+The http request timeout.
+
+=back
 
 =head2 clean($paths, %options)
 
